@@ -11,6 +11,7 @@ import json
 import logging
 import os
 import sys
+import typing as t
 from io import StringIO
 from tempfile import TemporaryDirectory
 from unittest import TestCase
@@ -21,12 +22,8 @@ from pytest import mark
 from traitlets import Bool, Bytes, Dict, HasTraits, Integer, List, Set, Tuple, Unicode
 from traitlets.config.application import Application
 from traitlets.config.configurable import Configurable
-from traitlets.config.loader import Config
-from traitlets.tests.utils import (
-    check_help_all_output,
-    check_help_output,
-    get_output_error_code,
-)
+from traitlets.config.loader import Config, KVArgParseConfigLoader
+from traitlets.tests.utils import check_help_all_output, check_help_output, get_output_error_code
 
 try:
     from unittest import mock
@@ -68,7 +65,7 @@ class MyApp(Application):
 
     name = Unicode("myapp")
     running = Bool(False, help="Is the app running?").tag(config=True)
-    classes = List([Bar, Foo])
+    classes = List([Bar, Foo])  # type:ignore
     config_file = Unicode("", help="Load this config file").tag(config=True)
 
     warn_tpyo = Unicode(
@@ -77,7 +74,7 @@ class MyApp(Application):
         help="Should print a warning if `MyApp.warn-typo=...` command is passed",
     )
 
-    aliases = {}
+    aliases: t.Dict[t.Any, t.Any] = {}
     aliases.update(Application.aliases)
     aliases.update(
         {
@@ -94,7 +91,7 @@ class MyApp(Application):
         }
     )
 
-    flags = {}
+    flags: t.Dict[t.Any, t.Any] = {}
     flags.update(Application.flags)
     flags.update(
         {
@@ -137,9 +134,13 @@ class TestApplication(TestCase):
         app = MyApp()
         self.assertEqual(app.name, "myapp")
         self.assertEqual(app.running, False)
-        self.assertEqual(app.classes, [MyApp, Bar, Foo])
+        self.assertEqual(app.classes, [MyApp, Bar, Foo])  # type:ignore
         self.assertEqual(app.config_file, "")
 
+    def test_app_name_set_via_constructor(self):
+        app = MyApp(name='set_via_constructor')
+        assert app.name == "set_via_constructor"
+
     def test_mro_discovery(self):
         app = MyApp()
 
@@ -371,6 +372,24 @@ class TestApplication(TestCase):
         app.init_foo()
         self.assertEqual(app.foo.j, 10)
 
+    def test_aliases_multiple(self):
+        # Test multiple > 2 aliases for the same argument
+        class TestMultiAliasApp(Application):
+            foo = Integer(config=True)
+            aliases = {("f", "bar", "qux"): "TestMultiAliasApp.foo"}
+
+        app = TestMultiAliasApp()
+        app.parse_command_line(["-f", "3"])
+        self.assertEqual(app.foo, 3)
+
+        app = TestMultiAliasApp()
+        app.parse_command_line(["--bar", "4"])
+        self.assertEqual(app.foo, 4)
+
+        app = TestMultiAliasApp()
+        app.parse_command_line(["--qux", "5"])
+        self.assertEqual(app.foo, 5)
+
     def test_aliases_help_msg(self):
         app = MyApp()
         stdout = io.StringIO()
@@ -383,6 +402,30 @@ class TestApplication(TestCase):
         self.assertIn("Equivalent to: [--Foo.j]", hmsg)
         self.assertIn("Equivalent to: [--Foo.name]", hmsg)
 
+    def test_alias_unrecognized(self):
+        """Check ability to override handling for unrecognized aliases"""
+
+        class StrictLoader(KVArgParseConfigLoader):
+            def _handle_unrecognized_alias(self, arg):
+                self.parser.error("Unrecognized alias: %s" % arg)
+
+        class StrictApplication(Application):
+            def _create_loader(self, argv, aliases, flags, classes):
+                return StrictLoader(argv, aliases, flags, classes=classes, log=self.log)
+
+        app = StrictApplication()
+        app.initialize(["--log-level=20"])  # recognized alias
+        assert app.log_level == 20
+
+        app = StrictApplication()
+        with pytest.raises(SystemExit, match="2"):
+            app.initialize(["--unrecognized=20"])
+
+        # Ideally we would use pytest capsys fixture, but fixtures are incompatible
+        # with unittest.TestCase-style classes :(
+        # stderr = capsys.readouterr().err
+        # assert "Unrecognized alias: unrecognized" in stderr
+
     def test_flag_clobber(self):
         """test that setting flags doesn't clobber existing settings"""
         app = MyApp()
@@ -477,7 +520,7 @@ class TestApplication(TestCase):
             pass
 
         app = MyApp()
-        app.classes.append(NoTraits)
+        app.classes.append(NoTraits)  # type:ignore
 
         conf_txt = app.generate_config_file()
         print(conf_txt)
@@ -594,6 +637,9 @@ class TestApplication(TestCase):
         self.assertIs(app.subapp.parent, app)
         self.assertIs(app.subapp.subapp.parent, app.subapp)  # Set by factory.
 
+        Root.clear_instance()
+        Sub1.clear_instance()
+
     def test_loaded_config_files(self):
         app = MyApp()
         app.log = logging.getLogger()
@@ -621,7 +667,7 @@ class TestApplication(TestCase):
 
             # Attempt to update, ensure error...
             with self.assertRaises(AttributeError):
-                app.loaded_config_files = "/foo"
+                app.loaded_config_files = "/foo"  # type:ignore
 
             # ensure it can't be udpated via append
             app.loaded_config_files.append("/bar")
@@ -665,7 +711,7 @@ class Sub2(Application):
 
 
 class Sub1(Application):
-    subcommands = {
+    subcommands: dict = {  # type:ignore
         "sub2": (Sub2, "Application class"),
         "sub3": (lambda root: Sub3(parent=root, flag=True), "factory"),
     }
